#ifndef TESTCLIPTOPAGE_H
#define TESTCLIPTOPAGE_H

#include <QObject>
#include <QtTest/QtTest>

class TestClipToPage : public QObject
{
    Q_OBJECT
private slots: // tests
    void testClipToPage();
};

#endif
